@@ -206,12 +206,12 @@ class Torrent(object):
         options (dict): The torrent options.
         state (TorrentState): The torrent state.
         filename (str): The filename of the torrent file.
-        magnet (str): The magnet uri.
+        magnet (str): The magnet URI.
 
     Attributes:
         torrent_id (str): The torrent_id for this torrent
         handle: Holds the libtorrent torrent handle
-        magnet (str): The magnet uri used to add this torrent (if available).
+        magnet (str): The magnet URI used to add this torrent (if available).
         status: Holds status info so that we don"t need to keep getting it from libtorrent.
         torrent_info: store the torrent info.
         has_metadata (bool): True if the metadata for the torrent is available, False otherwise.
@@ -266,6 +266,9 @@ class Torrent(object):
             self.is_finished = False
             self.filename = filename
 
+        if not self.filename:
+            self.filename = ''
+
         self.forced_error = None
         self.statusmsg = None
         self.state = None
@@ -428,14 +431,14 @@ class Torrent(object):
         # Setting the priorites for all the pieces of this torrent
         self.handle.prioritize_pieces(priorities)
 
-    def set_sequential_download(self, set_sequencial):
+    def set_sequential_download(self, sequential):
         """Sets whether to download the pieces of the torrent in order.
 
         Args:
-            set_sequencial (bool): Enable sequencial downloading.
+            sequential (bool): Enable sequential downloading.
         """
-        self.options['sequential_download'] = set_sequencial
-        self.handle.set_sequential_download(set_sequencial)
+        self.options['sequential_download'] = sequential
+        self.handle.set_sequential_download(sequential)
 
     def set_auto_managed(self, auto_managed):
         """Set auto managed mode, i.e. will be started or queued automatically.
@@ -810,7 +813,11 @@ class Torrent(object):
             if peer.flags & peer.connecting or peer.flags & peer.handshake:
                 continue
 
-            client = decode_bytes(peer.client)
+            try:
+                client = decode_bytes(peer.client)
+            except UnicodeDecodeError:
+                # libtorrent on Py3 can raise UnicodeDecodeError for peer_info.client
+                client = 'unknown'
 
             try:
                 country = component.get('Core').geoip_instance.country_code_by_addr(
@@ -867,11 +874,18 @@ class Torrent(object):
         """
         if not self.has_metadata:
             return []
-        return [
-            progress / _file.size if _file.size else 0.0
-            for progress, _file in zip(
+
+        try:
+            files_progresses = zip(
                 self.handle.file_progress(), self.torrent_info.files()
             )
+        except Exception:
+            # Handle libtorrent >=2.0.0,<=2.0.4 file_progress error
+            files_progresses = zip(iter(lambda: 0, 1), self.torrent_info.files())
+
+        return [
+            progress / _file.size if _file.size else 0.0
+            for progress, _file in files_progresses
         ]
 
     def get_tracker_host(self):
@@ -913,7 +927,7 @@ class Torrent(object):
         return ''
 
     def get_magnet_uri(self):
-        """Returns a magnet uri for this torrent"""
+        """Returns a magnet URI for this torrent"""
         return lt.make_magnet_uri(self.handle)
 
     def get_name(self):
@@ -987,6 +1001,8 @@ class Torrent(object):
                 call to get_status based on the session_id
             update (bool): If True the status will be updated from libtorrent
                 if False, the cached values will be returned
+            all_keys (bool): If True return all keys while ignoring the keys param
+                if False, return only the requested keys
 
         Returns:
             dict: a dictionary of the status keys and their values
@@ -1208,8 +1224,8 @@ class Torrent(object):
             bool: True is successful, otherwise False
         """
         try:
-            self.handle.connect_peer((peer_ip, peer_port), 0)
-        except RuntimeError as ex:
+            self.handle.connect_peer((peer_ip, int(peer_port)), 0)
+        except (RuntimeError, ValueError) as ex:
             log.debug('Unable to connect to peer: %s', ex)
             return False
         return True
@@ -1312,7 +1328,7 @@ class Torrent(object):
         torrent_files = [
             os.path.join(get_config_dir(), 'state', self.torrent_id + '.torrent')
         ]
-        if delete_copies:
+        if delete_copies and self.filename:
             torrent_files.append(
                 os.path.join(self.config['torrentfiles_location'], self.filename)
             )
@@ -1336,8 +1352,8 @@ class Torrent(object):
     def scrape_tracker(self):
         """Scrape the tracker
 
-         A scrape request queries the tracker for statistics such as total
-         number of incomplete peers, complete peers, number of downloads etc.
+        A scrape request queries the tracker for statistics such as total
+        number of incomplete peers, complete peers, number of downloads etc.
         """
         try:
             self.handle.scrape_tracker()
@@ -1384,7 +1400,7 @@ class Torrent(object):
         This basically does a file rename on all of the folders children.
 
         Args:
-            folder (str): The orignal folder name
+            folder (str): The original folder name
             new_folder (str): The new folder name
 
         Returns:
